Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type Activity ¶
type Activity struct {
// contains filtered or unexported fields
}
Activity is a kafka activity
type KafkaConnection ¶
type KafkaConnection struct {
// contains filtered or unexported fields
}
func (*KafkaConnection) Connection ¶
func (c *KafkaConnection) Connection() sarama.SyncProducer
func (*KafkaConnection) Stop ¶
func (c *KafkaConnection) Stop() error
type Output ¶
type Settings ¶
type Settings struct {
BrokerUrls string `md:"brokerUrls,required"` // The Kafka cluster to connect to
User string `md:"user"` // If connecting to a SASL enabled port, the user id to use for authentication
Password string `md:"password"` // If connecting to a SASL enabled port, the password to use for authentication
TrustStore string `md:"trustStore"` // If connecting to a TLS secured port, the directory containing the certificates representing the trust chain for the connection. This is usually just the CACert used to sign the server's certificate
Topic string `md:"topic,required"` // The Kafka topic on which to place the message
}
Click to show internal directories.
Click to hide internal directories.